@@ -12,7 +12,7 @@ from mxcubeweb.core.models.configmodels import ResourceHandlerConfigModel
 from mxcubeweb.core.util.networkutils import RateLimited
 
 resource_handler_config = ResourceHandlerConfigModel(
-    commands=["get_value", "set_value", "stop"], attributes=["data"]
+    commands=["set_value", "stop"], attributes=["data", "get_value"]
 )
 
 hwr_logger = logging.getLogger("MX3.HWR")
@@ -53,7 +53,7 @@ class ActuatorAdapter(ActuatorAdapterBase):
     def _value_change(self, *args, **kwargs):
         self._vc(*args, **kwargs)
 
-    def set_value(self, value: HOActuatorValueChangeModel):
+    def set_value(self, value: HOActuatorValueChangeModel) -> str:
         """
         Execute the sequence to set the value.
         Args:
@@ -66,6 +66,7 @@ class ActuatorAdapter(ActuatorAdapterBase):
             StopItteration: When a value change was interrupted (abort/cancel).
         """
         self._ho.set_value(float(value.value))
+        return self.get_value()
 
     def get_value(self) -> FloatValueModel:
         """
