@@ -374,7 +374,7 @@ class SampleView(ComponentBase):
 
     def start_manual_centring(self):
         """
-        Start 3 click centring procedure.
+        Start Click centring procedure.
             :statuscode: 200: no error
             :statuscode: 409: error
         """
@@ -384,11 +384,13 @@ class SampleView(ComponentBase):
                     "Aborting current centring ..."
                 )
                 HWR.beamline.diffractometer.cancel_centring_method(reject=True)
-
-            logging.getLogger("user_level_log").info("Centring using 3-click centring")
+            msg = "Centring using %s-click centring"
+            logging.getLogger("user_level_log").info(
+                msg, HWR.beamline.config.click_centring_num_clicks
+            )
 
             HWR.beamline.diffractometer.start_centring_method(
-                HWR.beamline.diffractometer.MANUAL3CLICK_MODE
+                HWR.beamline.diffractometer.CENTRING_METHOD_MANUAL
             )
 
             self.centring_reset_click_count()
@@ -422,7 +424,7 @@ class SampleView(ComponentBase):
                 HWR.beamline.diffractometer.cancel_centring_method()
 
                 HWR.beamline.diffractometer.start_centring_method(
-                    HWR.beamline.diffractometer.MANUAL3CLICK_MODE
+                    HWR.beamline.diffractometer.CENTRING_METHOD_MANUAL
                 )
 
         return {"clicksLeft": self.centring_clicks_left()}
